<?php
$translations = array(
	'General_Locale' => 'gl_ES.UTF-8',
	'General_TranslatorName' => 'OUSLI - Ourense Software Libre, Antonio Andina',
	'General_TranslatorEmail' => 'info@ousli.org',
	'General_EnglishLanguageName' => 'Galician',
	'General_OriginalLanguageName' => 'Galego',
	'General_HelloUser' => 'Ola, %s!',
	'General_OpenSourceWebAnalytics' => 'Analise Web de Open Source',
	'General_Dashboard' => 'Tableiro',
	'General_DashboardForASpecificWebsite' => 'Tableiro dunha soa Web',
	'General_MultiSitesSummary' => 'Todas as Webs',
	'General_AllWebsitesDashboard' => 'Tableiro de todas as Webs',
	'General_API' => 'API',
	'General_Widgets' => 'Engadidos',
	'General_Settings' => 'Configuración',
	'General_GiveUsYourFeedback' => 'Contacte con Nos',
	'General_Unknown' => 'Descoñecido',
	'General_Never' => 'Nunca',
	'General_Required' => '%s necesario',
	'General_NotValid' => '%s non é valido',
	'General_Id' => 'ID',
	'General_Error' => 'Erro',
	'General_Warning' => 'Advertencia',
	'General_BackToHomepage' => 'Voltar á páxina de inicio',
	'General_Yes' => 'Si',
	'General_No' => 'Non',
	'General_Delete' => 'Borrar',
	'General_Report' => 'Informe',
	'General_Edit' => 'Editar',
	'General_Download' => 'Descarga',
	'General_Ok' => 'Ok',
	'General_Close' => 'Pechar',
	'General_OrCancel' => 'ou %s Cancelar %s',
	'General_Logout' => 'Desconectarse',
	'General_Username' => 'Usuario',
	'General_Description' => 'Descripción',
	'General_Done' => 'Feito',
	'General_Name' => 'Nome',
	'General_Value' => 'Valor',
	'General_Details' => 'Detalle',
	'General_Default' => 'Predeterminado',
	'General_Visit' => 'Visita',
	'General_VisitorIP' => 'IP Visita',
	'General_VisitType' => 'Tipo Visitante',
	'General_DaysSinceLastVisit' => 'Días desde Última Visita',
	'General_DaysSinceFirstVisit' => 'Días desde Primeira Visita',
	'General_NumberOfVisits' => 'Número de Visitas',
	'General_VisitConvertedGoal' => 'Visita convertida en Obxectivo',
	'General_NewVisitor' => 'Nova Visita',
	'General_ReturningVisitor' => 'Re-Visita',
	'General_Date' => 'Data',
	'General_Period' => 'Periodo',
	'General_ChooseDate' => 'Escolla Data',
	'General_Today' => 'Hoxe',
	'General_Yesterday' => 'Onte',
	'General_CurrentWeek' => 'Semana Actual',
	'General_CurrentMonth' => 'Mes Actual',
	'General_CurrentYear' => 'Ano Actual',
	'General_DateRange' => 'Rango de Datas',
	'General_LoadingData' => 'Cargando Datos...',
	'General_Loading_js' => 'Cargando',
	'General_GoTo' => 'Ir a %s',
	'General_Next' => 'Seguinte',
	'General_Previous' => 'Anterior',
	'General_Search' => 'Procurar',
	'General_Others' => 'Outros',
	'General_Table' => 'Táboa',
	'General_Piechart' => 'Gráfico circular',
	'General_TagCloud' => 'Nube de etiquetas',
	'General_VBarGraph' => 'Gráfico de barras',
	'General_OpenInNewWindow_js' => 'Abrir en nova Xanela',
	'General_SaveImageOnYourComputer_js' => 'Para grabar a imaxe no computador faga click-dereito na imaxe e seleccione "Grabar Imaxe como.."',
	'General_Refresh' => 'Actualizar páxina',
	'General_Visitors' => 'Visitantes',
	'General_ExportThisReport' => 'Exportar datos noutros formatos',
	'General_ExportAsImage_js' => 'Exportar como Imaxe',
	'General_YourChangesHaveBeenSaved' => 'Os cambios foron grabados',
	'General_ErrorRequest' => 'Oops… Problema durante a petición, por favor probe de novo.',
	'General_ColumnNbUniqVisitors' => 'Visitantes únicos',
	'General_ColumnNbVisits' => 'Visitas',
	'General_ColumnPercentageVisits' => '% Visitas',
	'General_ColumnNbActions' => 'Accións',
	'General_NbActions' => 'Numero de Accións',
	'General_ColumnMaxActions' => 'Máximas accións nunha visita',
	'General_ColumnSumVisitLength' => 'Tempo por visitantes (en segundos)',
	'General_ColumnLabel' => 'Etiqueta',
	'General_ColumnConversionRate' => 'Tasa de Conversión',
	'General_ColumnActionsPerVisit' => 'Accións por Visita',
	'General_VisitDuration' => 'Duración Media Visita (en segs)',
	'General_ColumnAvgTimeOnSite' => 'Tempo Medio na Web',
	'General_ColumnVisitDuration' => 'Duración Visita (en segs)',
	'General_ColumnBounceRate' => 'Ratio de Rebotes',
	'General_ColumnExitRate' => 'Tasa de Saídas',
	'General_ColumnPageviews' => 'Páxinas Vistas',
	'General_ColumnUniquePageviews' => 'Páxinas Únicas',
	'General_ColumnBounces' => 'Rebotes',
	'General_ColumnEntrances' => 'Entradas',
	'General_ColumnExits' => 'Saídas',
	'General_ColumnAverageTimeOnPage' => 'Tempo medio na pax.',
	'General_ColumnValuePerVisit' => 'Valor por Visita',
	'General_ColumnVisitsWithConversions' => 'Visitas con Conversións',
	'General_YearsDays' => '%1$s anos %2$s días',
	'General_DaysHours' => '%1$s días %2$s horas',
	'General_HoursMinutes' => '%1$s horas %2$s min',
	'General_MinutesSeconds' => '%1$s min %2$segs',
	'General_Seconds' => '%segs',
	'General_Save' => 'Gardar',
	'General_ForExampleShort' => 'ex.',
	'General_YouMustBeLoggedIn' => 'Debes de rexistrate para acceder a esta función.',
	'General_Website' => 'Web',
	'General_GeneralSettings' => 'Configuración Xeral',
	'General_NSeconds' => '%s segs',
	'General_NoDataForGraph' => 'Sin datos para este Gráfico',
	'General_NoDataForTagCloud' => 'Sin datos para esta Nube',
	'General_DisplaySimpleTable' => 'Amosar táboa sinxela',
	'General_DisplayTableWithMoreMetrics' => 'Amosar táboa con máis medidas',
	'General_DisplayTableWithGoalMetrics' => 'Amosar táboa con Obexctivos',
	'General_YouAreViewingDemoShortMessage' => 'Vostede esta vendo a demo de Piwik',
	'General_NewUpdatePiwikX' => 'Nova Actualización: Piwik %s',
	'General_AboutPiwikX' => 'Acerca de Piwik %s',
	'General_BackToPiwik' => 'Voltar a Piwik',
	'General_ShortMonth_1' => 'Xan',
	'General_ShortMonth_2' => 'Feb',
	'General_ShortMonth_3' => 'Mar',
	'General_ShortMonth_4' => 'Abr',
	'General_ShortMonth_5' => 'Mai',
	'General_ShortMonth_6' => 'Xuñ',
	'General_ShortMonth_7' => 'Xul',
	'General_ShortMonth_8' => 'Ago',
	'General_ShortMonth_9' => 'Set',
	'General_ShortMonth_10' => 'Out',
	'General_ShortMonth_11' => 'Nov',
	'General_ShortMonth_12' => 'Dec',
	'General_LongMonth_1' => 'Xaneiro',
	'General_LongMonth_2' => 'Febreiro',
	'General_LongMonth_3' => 'Marzo',
	'General_LongMonth_4' => 'Abril',
	'General_LongMonth_5' => 'Maio',
	'General_LongMonth_6' => 'Xuño',
	'General_LongMonth_7' => 'Xullo',
	'General_LongMonth_8' => 'Agosto',
	'General_LongMonth_9' => 'Setembro',
	'General_LongMonth_10' => 'Outubro',
	'General_LongMonth_11' => 'Novembro',
	'General_LongMonth_12' => 'Decembro',
	'General_ShortDay_1' => 'Lun',
	'General_ShortDay_2' => 'Mar',
	'General_ShortDay_3' => 'Mer',
	'General_ShortDay_4' => 'Xov',
	'General_ShortDay_5' => 'Ven',
	'General_ShortDay_6' => 'Sab',
	'General_ShortDay_7' => 'Dom',
	'General_LongDay_1' => 'Lúns',
	'General_LongDay_2' => 'Martes',
	'General_LongDay_3' => 'Mércores',
	'General_LongDay_4' => 'Xoves',
	'General_LongDay_5' => 'Venres',
	'General_LongDay_6' => 'Sábado',
	'General_LongDay_7' => 'Domingo',
	'General_Daily' => 'Diariamente',
	'General_Weekly' => 'Semanalmente',
	'General_Monthly' => 'Mensualmente',
	'Actions_SubmenuPages' => 'Páxinas',
	'Actions_SubmenuOutlinks' => 'Ligazóns externos',
	'Actions_SubmenuDownloads' => 'Descargas',
	'API_LoadedAPIs' => '%s APIs foro cargadas con éxito',
	'CoreHome_CategoryNoData' => 'Non hai datos nesta categoría. Intente "Incluir todos os datos".',
	'CoreHome_ShowJSCode' => 'Ver o código javascript para insertar',
	'CoreHome_PageOf_js' => '%1$s de %2$s',
	'CoreHome_PeriodDay' => 'Día',
	'CoreHome_PeriodWeek' => 'Semana',
	'CoreHome_PeriodMonth' => 'Mes',
	'CoreHome_PeriodYear' => 'Ano',
	'CoreHome_DaySu_js' => 'D',
	'CoreHome_DayMo_js' => 'L',
	'CoreHome_DayTu_js' => 'M',
	'CoreHome_DayWe_js' => 'X',
	'CoreHome_DayTh_js' => 'J',
	'CoreHome_DayFr_js' => 'V',
	'CoreHome_DaySa_js' => 'S',
	'CoreHome_MonthJanuary_js' => 'Xaneiro',
	'CoreHome_MonthFebruary_js' => 'Febreiro',
	'CoreHome_MonthMarch_js' => 'Marzo',
	'CoreHome_MonthApril_js' => 'Abril',
	'CoreHome_MonthMay_js' => 'Maio',
	'CoreHome_MonthJune_js' => 'Xuño',
	'CoreHome_MonthJuly_js' => 'Xullo',
	'CoreHome_MonthAugust_js' => 'Agosto',
	'CoreHome_MonthSeptember_js' => 'Setembro',
	'CoreHome_MonthOctober_js' => 'Outubro',
	'CoreHome_MonthNovember_js' => 'Novembro',
	'CoreHome_MonthDecember_js' => 'Decembro',
	'CorePluginsAdmin_Plugins' => 'Plugins',
	'CorePluginsAdmin_Activated' => 'Activado',
	'CorePluginsAdmin_Deactivate' => 'Desactivar',
	'CorePluginsAdmin_Activate' => 'Activar',
	'CorePluginsAdmin_MenuPlugins' => 'Plugins',
	'Dashboard_DeleteWidgetConfirm' => '¿Está seguro de que desexa borrar este widget desde el tablón?',
	'Dashboard_SelectWidget' => 'Seleccione un widget para engadilo no tablón',
	'Dashboard_TitleWidgetInDashboard_js' => 'O widget xa se atopa no taboleiro',
	'Dashboard_TitleClickToAdd_js' => 'Clic para engadir ao taboleiro',
	'Dashboard_LoadingWidget_js' => 'Cargando widget, agarde por favor...',
	'Dashboard_WidgetNotFound_js' => 'Widget non atopado',
	'Installation_Installation' => 'Instalación',
	'Installation_InstallationStatus' => 'Estado da instalación',
	'Installation_PercentDone' => '%s %%Hecho',
	'Installation_NoConfigFound' => 'O ficheiro de configuración de Piwik non se atopou e vostede está tentando acceder a unha páxina de Piwik.<br><b>  » Pode <a href=\'index.php\'>instalar Piwik agora</a></b><br><small>Se instalou Piwik con anterioridade e ten táboas na súa base de datos, non se preocupe, pode reutilizar ditas táboas e manter os datos que se atopan nelas!</small>',
	'Installation_JsTag' => 'Etiqueta Javascript',
	'Installation_Congratulations' => 'Noraboa!',
	'Installation_CongratulationsHelp' => '<p>Noraboa! A instalación de Piwik foi completada.</p><p>Asegúrese de inserir o código Javascript en todas as páxinas, e agora, agarde aos primeiros visitantes!</p>',
	'Installation_SetupWebsite' => 'Configurar unha páxina web',
	'Installation_SetupWebsiteError' => 'Houbo un erro ao engadir o sitio',
	'Installation_SystemCheck' => 'Comprobación do sitio',
	'Installation_SystemCheckPhp' => 'Versión PHP',
	'Installation_SystemCheckWriteDirs' => 'Directorios con permisos de escrita',
	'Installation_SystemCheckWriteDirsHelp' => 'Para arranxar este erro no seu sistema GNU/Linux, tente inserindo os seguintes comandos',
	'Installation_SystemCheckMemoryLimit' => 'Límite de memoria',
	'Installation_SystemCheckMemoryLimitHelp' => 'Nun sitio web cun tráfico elevado, o proceso de arquivado pode requirir máis memoria da que está dispoñible.<br>Mire o apartado memory_limit no seu ficheiro php.ini se é necesario.',
	'Installation_SystemCheckGD' => 'GD > 2.x (gráficos)',
	'Installation_SystemCheckGDHelp' => 'Os sparklines (gráficos pequenos) non funcionarán.',
	'Installation_SystemCheckTimeLimitHelp' => 'Nun sitio web cun tráfico elevado, o proceso de arquivado pode requirir máis memoria da que está dispoñible.<br>Mire a directiva max_execution_time no seu ficheiro php.ini se fose necesario',
	'Installation_SystemCheckError' => 'Houbo un erro - Debe arranxarse antes de continuar',
	'Installation_SystemCheckWarning' => 'Piwik traballará correctamente, pero algunhas características poden faltar',
	'Installation_Tables' => 'Creando as táboas',
	'Installation_TablesFound' => 'As seguintes táboas atopáronse na base de datos',
	'Installation_TablesWarningHelp' => 'Ou ben optar pola reutilización de táboas de bases de datos existentes ou seleccionar unha instalación limpa para eliminar todos os datos existentes na base de datos.',
	'Installation_TablesReuse' => 'Reutilizar as táboas xa existentes',
	'Installation_TablesDelete' => 'Eliminar as táboas detectadas',
	'Installation_TablesDeletedSuccess' => 'Táboas existentes de piwik eliminadas con éxito',
	'Installation_TablesCreatedSuccess' => 'Táboas creadas con éxito!',
	'Installation_Welcome' => 'Benvido!',
	'Installation_WelcomeHelp' => '<p>Piwik é unha aplicación de código aberto de estatísticas que che permitirá recompilar información sobre o teu sitio facilmente.</p><p>Este proceso divídese en %s pasos sinxelos que levarán uns 5 minutos.</p>',
	'Login_LoginPasswordNotCorrect' => 'Usuario e contrasinal incorrectos',
	'Login_Password' => 'Contrasinal',
	'Login_LoginOrEmail' => 'Login ou E-mail',
	'Login_LogIn' => 'Conectar',
	'Login_Logout' => 'Desconectar',
	'Login_LostYourPassword' => 'Esqueceu o contrasinal?',
	'Login_InvalidUsernameEmail' => 'O nome do usuario ou o enderezo de correo electrónicoo son incorrectos',
	'Login_ContactAdmin' => 'Posible razón: o seu aloxamento pode ter deshabilitado a función mail().<br>Por favor contacte co seu administrador de piwik.',
	'Provider_WidgetProviders' => 'Provedores',
	'Provider_SubmenuLocationsProvider' => 'Localizacións e provedor',
	'Referers_SearchEngines' => 'Motores de busca',
	'Referers_Keywords' => 'Palabras clave',
	'Referers_DirectEntry' => 'Entrada directa',
	'Referers_Websites' => 'Páxinas web',
	'Referers_Campaigns' => 'Campañas',
	'Referers_Evolution' => 'Evolución no periodo',
	'Referers_Type' => 'Tipo de Referer',
	'Referers_TypeDirectEntries' => '%s entradas directas',
	'Referers_TypeSearchEngines' => '%s desde motores de busca',
	'Referers_TypeWebsites' => '%s desde outras webs',
	'Referers_TypeCampaigns' => '%s desde campañas',
	'Referers_SubmenuSearchEngines' => 'Motores de busca e palabras clave',
	'Referers_SubmenuWebsites' => 'Páxinas web',
	'Referers_SubmenuCampaigns' => 'Campañas',
	'Referers_WidgetKeywords' => 'Lista de palabras clave',
	'Referers_WidgetCampaigns' => 'Lista de campañas',
	'Referers_WidgetExternalWebsites' => 'Lista de webs externas',
	'Referers_WidgetSearchEngines' => 'Mellores motores de busca',
	'Referers_WidgetOverview' => 'Xeral',
	'SitesManager_Sites' => 'Sitios',
	'SitesManager_NoWebsites' => 'Vostede non ten ningunha web que administrar',
	'SitesManager_AddSite' => 'Engadir un sitio',
	'SitesManager_Urls' => 'URLs',
	'SitesManager_MenuSites' => 'Sitios',
	'SitesManager_DeleteConfirm_js' => 'Está seguro de querer eliminar o sitio %s?',
	'SitesManager_ExceptionDeleteSite' => 'Non é posible eliminar este sitio xa que é o único que hai rexistrado. Antes de eliminalo, engada un novo.',
	'SitesManager_ExceptionNoUrl' => 'Debe especificar polo menos unha URL do seu sitio.',
	'SitesManager_ExceptionEmptyName' => 'O nome do sitio non pode estar baleiro.',
	'SitesManager_ExceptionInvalidUrl' => 'A URL \'%s\' non é unha URL válida.',
	'TranslationsAdmin_MenuTranslations' => 'Traducións',
	'TranslationsAdmin_MenuLanguages' => 'Idiomas',
	'TranslationsAdmin_LanguageCode' => 'Código de idioma',
	'TranslationsAdmin_Plugin' => 'Complemento',
	'TranslationsAdmin_Definition' => 'Definición',
	'TranslationsAdmin_DefaultString' => 'Cadea por defecto (Castelán)',
	'TranslationsAdmin_TranslationString' => 'Cadea traducida (Idioma actual: %s)',
	'TranslationsAdmin_Translations' => 'Traducións',
	'TranslationsAdmin_FixPermissions' => 'Por favor arranxe os permisos dos ficheiros',
	'TranslationsAdmin_AddLanguage' => 'Engadir un idioma',
	'TranslationsAdmin_Export' => 'Exportar idioma',
	'TranslationsAdmin_Import' => 'Importar idioma',
	'UserCountry_Country' => 'País',
	'UserCountry_Continent' => 'Continente',
	'UserCountry_DistinctCountries' => '%s continentes distintos',
	'UserCountry_SubmenuLocations' => 'Lugares',
	'UserCountry_country_ac' => 'Isla Ascensión',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'Emiratos Árabes Unidos',
	'UserCountry_country_af' => 'Afganistán',
	'UserCountry_country_ag' => 'Antigua y Barbuda',
	'UserCountry_country_ai' => 'Anguila',
	'UserCountry_country_al' => 'Albania',
	'UserCountry_country_am' => 'Armenia',
	'UserCountry_country_an' => 'Antillas Neerlandesas',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antártida',
	'UserCountry_country_ar' => 'Arxentina',
	'UserCountry_country_as' => 'América Samoa',
	'UserCountry_country_at' => 'Austria',
	'UserCountry_country_au' => 'Australia',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_az' => 'Azerbaiyán',
	'UserCountry_country_ba' => 'Bosnia Herzegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladesh',
	'UserCountry_country_be' => 'Bélxica',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgaria',
	'UserCountry_country_bh' => 'Bahrein',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bm' => 'Bermudas',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Bolivia',
	'UserCountry_country_br' => 'Brasil',
	'UserCountry_country_bs' => 'Bahamas',
	'UserCountry_country_bt' => 'Bután',
	'UserCountry_country_bv' => 'Isla Bouvet',
	'UserCountry_country_bw' => 'Botsuana',
	'UserCountry_country_by' => 'Bielorrusia',
	'UserCountry_country_bz' => 'Belice',
	'UserCountry_country_ca' => 'Canadá',
	'UserCountry_country_cc' => 'Islas Cocos',
	'UserCountry_country_cd' => 'Congo, A República Democrática',
	'UserCountry_country_cf' => 'República Centroafricana',
	'UserCountry_country_cg' => 'Congo',
	'UserCountry_country_ch' => 'Suiza',
	'UserCountry_country_ci' => 'Cote D\'Ivoire',
	'UserCountry_country_ck' => 'Islas Cook',
	'UserCountry_country_cl' => 'Chile',
	'UserCountry_country_cm' => 'Camerún',
	'UserCountry_country_cn' => 'China',
	'UserCountry_country_co' => 'Colombia',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Serbia Montenegro',
	'UserCountry_country_cu' => 'Cuba',
	'UserCountry_country_cv' => 'Cabo verde',
	'UserCountry_country_cx' => 'Islas Christmas',
	'UserCountry_country_cy' => 'Chipre',
	'UserCountry_country_cz' => 'República Checa',
	'UserCountry_country_de' => 'Alemaña',
	'UserCountry_country_dj' => 'Yibuti',
	'UserCountry_country_dk' => 'Dinamarca',
	'UserCountry_country_dm' => 'Dominica',
	'UserCountry_country_do' => 'República Dominicana',
	'UserCountry_country_dz' => 'Arxelia',
	'UserCountry_country_ec' => 'Ecuador',
	'UserCountry_country_ee' => 'Estonia',
	'UserCountry_country_eg' => 'Exipto',
	'UserCountry_country_eh' => 'Sáhara Occidental',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'España',
	'UserCountry_country_et' => 'Etiopía',
	'UserCountry_country_fi' => 'Finlandia',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Malvinas',
	'UserCountry_country_fm' => 'Micronesia, Estados Federados',
	'UserCountry_country_fo' => 'Islas Feroe',
	'UserCountry_country_fr' => 'Francia',
	'UserCountry_country_ga' => 'Gabón',
	'UserCountry_country_gb' => 'Gran Bretaña',
	'UserCountry_country_gd' => 'Granada',
	'UserCountry_country_ge' => 'Xeorxia',
	'UserCountry_country_gf' => 'Guayana Francesa',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Xibraltar',
	'UserCountry_country_gl' => 'Groenlandia',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Guinea',
	'UserCountry_country_gp' => 'Guadalupe',
	'UserCountry_country_gq' => 'Guinea Ecuatorial',
	'UserCountry_country_gr' => 'Grecia',
	'UserCountry_country_gs' => 'Islas Georgia del Sur y Sandwich del Sur',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guayana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Islas Heard y McDonald',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Croacia',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Hungría',
	'UserCountry_country_id' => 'Indonesia',
	'UserCountry_country_ie' => 'Irlanda',
	'UserCountry_country_il' => 'Israel',
	'UserCountry_country_im' => 'Isla de Man',
	'UserCountry_country_in' => 'India',
	'UserCountry_country_io' => 'Territorio Británico do Océano Índico',
	'UserCountry_country_iq' => 'Iraq',
	'UserCountry_country_ir' => 'Irán, República Islámica',
	'UserCountry_country_is' => 'Islandia',
	'UserCountry_country_it' => 'Italia',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaica',
	'UserCountry_country_jo' => 'Xordania',
	'UserCountry_country_jp' => 'Xapón',
	'UserCountry_country_ke' => 'Kenia',
	'UserCountry_country_kg' => 'Kirguistán',
	'UserCountry_country_kh' => 'Camboia',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Comores',
	'UserCountry_country_kn' => 'San Kitts and Nevis',
	'UserCountry_country_kp' => 'Corea, República Democrática Popular de',
	'UserCountry_country_kr' => 'Corea, República de',
	'UserCountry_country_kw' => 'Kuwait',
	'UserCountry_country_ky' => 'Islas Caimán',
	'UserCountry_country_kz' => 'Kazajstán',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Líbano',
	'UserCountry_country_lc' => 'Santa Lucía',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Liberia',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Lituania',
	'UserCountry_country_lu' => 'Luxemburgo',
	'UserCountry_country_lv' => 'Letonia',
	'UserCountry_country_ly' => 'Libia',
	'UserCountry_country_ma' => 'Marruecos',
	'UserCountry_country_mc' => 'Mónaco',
	'UserCountry_country_md' => 'Moldavia, República de',
	'UserCountry_country_mg' => 'Madagascar',
	'UserCountry_country_mh' => 'Islas Marshall',
	'UserCountry_country_mk' => 'Macedonia',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongolia',
	'UserCountry_country_mo' => 'Macao',
	'UserCountry_country_mp' => 'Illas Marianas do Norte',
	'UserCountry_country_mq' => 'Martinica',
	'UserCountry_country_mr' => 'Mauritania',
	'UserCountry_country_ms' => 'Monserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Mauricio',
	'UserCountry_country_mv' => 'Maldivas',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'México',
	'UserCountry_country_my' => 'Malasia',
	'UserCountry_country_mz' => 'Mozambique',
	'UserCountry_country_na' => 'Namibia',
	'UserCountry_country_nc' => 'Nova Caledonia',
	'UserCountry_country_ne' => 'Níxer',
	'UserCountry_country_nf' => 'Illa Norfolk',
	'UserCountry_country_ng' => 'Nixeria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Países Baixos',
	'UserCountry_country_no' => 'Noruega',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'Nova Zelanda',
	'UserCountry_country_om' => 'Omán',
	'UserCountry_country_pa' => 'Panamá',
	'UserCountry_country_pe' => 'Perú',
	'UserCountry_country_pf' => 'Polinesia Francesa',
	'UserCountry_country_pg' => 'Papúa Nova Guinea',
	'UserCountry_country_ph' => 'Filipinas',
	'UserCountry_country_pk' => 'Pakistán',
	'UserCountry_country_pl' => 'Polonia',
	'UserCountry_country_pm' => 'San Pedro e Miguelón',
	'UserCountry_country_pn' => 'Pitcairn',
	'UserCountry_country_pr' => 'Porto Rico',
	'UserCountry_country_ps' => 'Territorio Palestino',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguai',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'Illa de Reunión',
	'UserCountry_country_ro' => 'Romanía',
	'UserCountry_country_rw' => 'Ruanda',
	'UserCountry_country_sa' => 'Arabia Saudí',
	'UserCountry_country_sb' => 'Illas Salomón',
	'UserCountry_country_sc' => 'Seychelles',
	'UserCountry_country_sd' => 'Sudán',
	'UserCountry_country_se' => 'Suiza',
	'UserCountry_country_sg' => 'Singapur',
	'UserCountry_country_sh' => 'Santa Helena',
	'UserCountry_country_si' => 'Eslovenia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Eslovaquia',
	'UserCountry_country_sl' => 'Serra Leoa',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somalia',
	'UserCountry_country_sr' => 'Surinam',
	'UserCountry_country_st' => 'Santo Tomé e Príncipe',
	'UserCountry_country_su' => 'Antiga U.R.S.S..',
	'UserCountry_country_sv' => 'O Salvador',
	'UserCountry_country_sy' => 'República Árabe Siria',
	'UserCountry_country_sz' => 'Suazilandia',
	'UserCountry_country_tc' => 'Illas Turcas e Caicos',
	'UserCountry_country_td' => 'Chad',
	'UserCountry_country_tf' => 'Territorios Franceses do Sur',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Tailandia',
	'UserCountry_country_tj' => 'Tayikistán',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tm' => 'Turkmenistán',
	'UserCountry_country_tn' => 'Túnez',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'Timor Oriental',
	'UserCountry_country_tr' => 'Turquía',
	'UserCountry_country_tt' => 'Trinidade e Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwán',
	'UserCountry_country_tz' => 'Tanzania, República Unida de',
	'UserCountry_country_ua' => 'Ucrania',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'Reino Unido',
	'UserCountry_country_um' => 'Illas Menores dos EEUU',
	'UserCountry_country_us' => 'Estados Unidos',
	'UserCountry_country_uy' => 'Uruguai',
	'UserCountry_country_uz' => 'Uzbekistán',
	'UserCountry_country_va' => 'Cidade do Vaticano',
	'UserCountry_country_vc' => 'San Vicente e as Graadinas',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Illas Virxes Británicas',
	'UserCountry_country_vi' => 'Illas Virxes, EE.UU.',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis e Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Iemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Iugoslavia',
	'UserCountry_country_za' => 'Sudáfrica',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabue',
	'UserCountry_continent_eur' => 'Europa',
	'UserCountry_continent_afr' => 'África',
	'UserCountry_continent_asi' => 'Asia',
	'UserCountry_continent_amn' => 'América do Norte',
	'UserCountry_continent_ams' => 'América do Sur e Central',
	'UserCountry_continent_oce' => 'Oceanía',
	'UserSettings_BrowserFamilies' => 'Familias de navegadores',
	'UserSettings_Browsers' => 'Navegadores',
	'UserSettings_Plugins' => 'Plugins',
	'UserSettings_Configurations' => 'Configuracións',
	'UserSettings_OperatingSystems' => 'Sistemas Operativos',
	'UserSettings_Resolutions' => 'Resolucións',
	'UserSettings_WideScreen' => 'Pantalla panorámica',
	'UserSettings_WidgetResolutions' => 'Resolucións de pantalla',
	'UserSettings_WidgetBrowsers' => 'Navegadores dos visitantes',
	'UserSettings_WidgetPlugins' => 'Lista de plugins',
	'UserSettings_WidgetWidescreen' => 'Normal / Panorámica',
	'UserSettings_WidgetBrowserFamilies' => 'Buscadores por familia',
	'UserSettings_WidgetOperatingSystems' => 'Sistemas Operativos',
	'UserSettings_WidgetGlobalVisitors' => 'Configuración global de visitantes',
	'UserSettings_SubmenuSettings' => 'Axustes',
	'UsersManager_ManageAccess' => 'Administrar o acceso',
	'UsersManager_Sites' => 'Sitios',
	'UsersManager_AllWebsites' => 'Todas as webs',
	'UsersManager_ApplyToAllWebsites' => 'Aplicar a todos os sitios',
	'UsersManager_User' => 'Usuario',
	'UsersManager_PrivNone' => 'Acceso denegado',
	'UsersManager_PrivView' => 'Ver',
	'UsersManager_PrivAdmin' => 'Admin',
	'UsersManager_ChangeAllConfirm' => 'Está seguro que quere cambiar \'%s\' permisos en todas as páxinas web?',
	'UsersManager_Password' => 'Contrasinal',
	'UsersManager_Email' => 'Enderezo electrónico',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_Edit' => 'Modificar',
	'UsersManager_AddUser' => 'Engadir un novo usuario',
	'UsersManager_MenuUsers' => 'Usuario',
	'UsersManager_DeleteConfirm_js' => 'Está seguro de que desexa eliminar ao usuario %s?',
	'UsersManager_ExceptionLoginExists' => 'O nome de usuario \'%s\' xa existe.',
	'UsersManager_ExceptionInvalidEmail' => 'O enderezo electrónico non ten un formato correcto.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'O usuario \'%s\' non existe, polo que non pode ser eliminado.',
	'UsersManager_ExceptionAdminAnonymous' => 'Non pode concederlle o acceso de \'administrador\' a un usuario \'anónimo\'.',
	'UsersManager_ExceptionEditAnonymous' => 'O usuario anónimo non pode ser eliminado ou modificado, xa que é empregado por Piwik para identificar a usuarios  non conectados. Por exemplo, pode facer as súas estatísticas públicas dando acceso á \'visión\' aos visitantes \'anónimos\'.',
	'UsersManager_ExceptionUserDoesNotExist' => 'O usuario \'%s\' non existe.',
	'UsersManager_ExceptionAccessValues' => 'O parámetro debe ter acceso a un dos seguintes valores: [%s]',
	'VisitFrequency_Evolution' => 'Evolución no período',
	'VisitFrequency_ReturnVisits' => '%s visitantes que voltaron',
	'VisitFrequency_ReturnActions' => '%s accións realizadas polos visitantes que voltaron',
	'VisitFrequency_WidgetOverview' => 'Listado de frecuencias',
	'VisitFrequency_WidgetGraphReturning' => 'Gráfico de visitantes que volven',
	'VisitFrequency_SubmenuFrequency' => 'Frecuencia',
	'VisitorInterest_VisitsPerDuration' => 'Visitas por duración',
	'VisitorInterest_VisitsPerNbOfPages' => 'Visitas por número de páxinas visitadas',
	'VisitorInterest_WidgetLengths' => 'Duración das visitas',
	'VisitorInterest_WidgetPages' => 'Páxinas vistas por visita',
	'VisitsSummary_NbVisits' => '%s visitas',
	'VisitsSummary_NbUniqueVisitors' => '%s visitas únicas',
	'VisitsSummary_MaxNbActions' => '%s accións máximas nunha visita',
	'VisitsSummary_GenerateTime' => '%s segundos para xerar a páxina',
	'VisitsSummary_GenerateQueries' => '%s consultas executadas',
	'VisitsSummary_WidgetLastVisits' => 'Gráfico das últimas visitas',
	'VisitsSummary_WidgetVisits' => 'Visión xeral de visitas',
	'VisitsSummary_WidgetLastVisitors' => 'Gráfico dos últimos visitantes únicos',
	'VisitsSummary_WidgetOverviewGraph' => 'Visión xeral con gráfico',
	'VisitsSummary_SubmenuOverview' => 'Visión xeral',
	'VisitTime_LocalTime' => 'Visitas por hora local',
	'VisitTime_ServerTime' => 'Visitas por hora do servidor',
	'VisitTime_WidgetLocalTime' => 'Visitas por hora local',
	'VisitTime_WidgetServerTime' => 'Visitas por hora do servidor',
	'VisitTime_SubmenuTimes' => 'Tempos',
);
